@@ -20,6 +20,14 @@ test_that("describe_service_integration", {
   expect_error(svc$describe_service_integration(), NA)
 })
 
+test_that("list_monitored_resources", {
+  expect_error(svc$list_monitored_resources(), NA)
+})
+
+test_that("list_monitored_resources", {
+  expect_error(svc$list_monitored_resources(MaxResults = 20), NA)
+})
+
 test_that("list_notification_channels", {
   expect_error(svc$list_notification_channels(), NA)
 })
